@@ -1,28 +1,30 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.pyson import Not, Equal, Eval
+from trytond.pyson import Eval
 from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 
 class SaleLine(ModelSQL, ModelView):
     _name = 'sale.line'
 
     analytic_accounts = fields.Many2One('analytic_account.account.selection',
-            'Analytic Accounts',
-            states={
-                'invisible': Not(Equal(Eval('type'), 'line')),
-            })
+        'Analytic Accounts',
+        states={
+            'invisible': Eval('type') != 'line',
+            },
+        depends=['type'])
 
-    def _view_look_dom_arch(self, tree, type):
-        analytic_account_obj = self.pool.get('analytic_account.account')
+    def _view_look_dom_arch(self, tree, type, field_children=None):
+        analytic_account_obj = Pool().get('analytic_account.account')
         analytic_account_obj.convert_view(tree)
-        arch, fields, = super(SaleLine, self)._view_look_dom_arch(tree, type)
+        arch, fields, = super(SaleLine, self)._view_look_dom_arch(tree, type,
+            field_children=field_children)
         return arch, fields
 
     def fields_get(self, fields_names=None):
-        analytic_account_obj = self.pool.get('analytic_account.account')
+        analytic_account_obj = Pool().get('analytic_account.account')
 
         res = super(SaleLine, self).fields_get(fields_names)
 
@@ -33,8 +35,13 @@ class SaleLine(ModelSQL, ModelView):
                 analytic_accounts_field, fields_names))
         return res
 
+    def default_get(self, fields, with_rec_name=True):
+        fields = [x for x in fields if not x.startswith('analytic_account_')]
+        return super(SaleLine, self).default_get(fields,
+            with_rec_name=with_rec_name)
+
     def read(self, ids, fields_names=None):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
 
         int_id = False
         if isinstance(ids, (int, long)):
@@ -84,7 +91,7 @@ class SaleLine(ModelSQL, ModelView):
         return res
 
     def create(self, vals):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
         vals = vals.copy()
         selection_vals = {}
         for field in vals.keys():
@@ -101,7 +108,7 @@ class SaleLine(ModelSQL, ModelView):
         return super(SaleLine, self).create(vals)
 
     def write(self, ids, vals):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
         vals = vals.copy()
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -142,7 +149,7 @@ class SaleLine(ModelSQL, ModelView):
         return super(SaleLine, self).write(ids, vals)
 
     def delete(self, ids):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
 
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -157,7 +164,7 @@ class SaleLine(ModelSQL, ModelView):
         return res
 
     def copy(self, ids, default=None):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
 
         new_ids = super(SaleLine, self).copy(ids, default=default)
 
@@ -178,7 +185,7 @@ class SaleLine(ModelSQL, ModelView):
         return new_ids
 
     def get_invoice_line(self, line):
-        account_selection_obj = self.pool.get('analytic_account.account.selection')
+        account_selection_obj = Pool().get('analytic_account.account.selection')
 
         res = super(SaleLine, self).get_invoice_line(line)
         if not res:
@@ -198,21 +205,21 @@ class Account(ModelSQL, ModelView):
     _name = 'analytic_account.account'
 
     def delete(self, ids):
-        sale_line_obj = self.pool.get('sale.line')
+        sale_line_obj = Pool().get('sale.line')
         res = super(Account, self).delete(ids)
         # Restart the cache on the fields_view_get method of sale.line
         sale_line_obj.fields_view_get.reset()
         return res
 
     def create(self, vals):
-        sale_line_obj = self.pool.get('sale.line')
+        sale_line_obj = Pool().get('sale.line')
         res = super(Account, self).create(vals)
         # Restart the cache on the fields_view_get method of sale.line
         sale_line_obj.fields_view_get.reset()
         return res
 
     def write(self, ids, vals):
-        sale_line_obj = self.pool.get('sale.line')
+        sale_line_obj = Pool().get('sale.line')
         res = super(Account, self).write(ids, vals)
         # Restart the cache on the fields_view_get method of sale.line
         sale_line_obj.fields_view_get.reset()
